ad_basereq: Generate a base request string for the AREAdata database

View source: R/ad_basereq.R

ad_basereqR Documentation

Generate a base request string for the AREAdata database

Description

This string is used as the basis for all calls to AREAdata. It does not contain any tokens or session ids, and thus can be regenerated at any time.

Usage

ad_basereq()

Value

Returns a string containing the root address of the AREAdata dataset.

Author(s)

Francis Windram

Examples

basereq <- ad_basereq()


ohvbd documentation built on March 10, 2026, 1:07 a.m.