coercedate: Try to coerce a date even when bits are missing

View source: R/utils.R

coercedateR Documentation

Try to coerce a date even when bits are missing

Description

Try to coerce a date even when bits are missing

Usage

coercedate(dates, return_iso = FALSE, nulliferror = FALSE)

Arguments

dates

The date/s to try and coerce.

Value

Coerced dates.


ohvbd documentation built on March 10, 2026, 1:07 a.m.