extract: Extract specified data from a set of responses (Deprecated)

View source: R/ohvbd-deprecated.R

extractR Documentation

Extract specified data from a set of responses (Deprecated)

Description

This is a convenience method that infers and applies the correct extractor for the input.

Usage

extract(res, ...)

Arguments

res

An object of type ohvbd.responses or ohvbd.ad.matrix generated from fetch() and containing data from one of the supported databases.

...

Any arguments to be passed to the underlying extractors (see glean_vt() and glean_ad() for specific arguments).

Value

The extracted data, either as an ohvbd.data.frame or ohvbd.ad.matrix object.

Note

extract() is now deprecated and should not be used. Please use glean() instead.

Author(s)

Francis Windram


ohvbd documentation built on March 10, 2026, 1:07 a.m.