fetch: Fetch specified data from a set of ids

View source: R/class_methods.R

fetchR Documentation

Fetch specified data from a set of ids

Description

This is a convenience method that infers and applies the correct fetch function for the input ids.

Usage

fetch(ids, ...)

Arguments

ids

An object of type ohvbd.ids (generated from a search, manually packaged using ohvbd.ids() or generated by another function).

...

Any other arguments to be passed to the underlying fetch functions (see fetch_vt() and fetch_vd() for specific arguments).

Value

The downloaded data, as an ohvbd.responses object.

Author(s)

Francis Windram

Examples


search_hub("Ixodes", "vt") |> fetch()


ohvbd documentation built on March 10, 2026, 1:07 a.m.