fetch_citations: Try to find the relevant citations for a dataset

View source: R/class_methods.R

fetch_citationsR Documentation

Try to find the relevant citations for a dataset

Description

This tries to extract and simplify the citations from a dataset downloaded using ohvbd.

Usage

fetch_citations(dataset, ...)

Arguments

dataset

An object of type ohvbd.data.frame (generated from glean(), preferred) or of type ohvbd.ids and containing data from one of the supported databases.

...

Any arguments to be passed to the underlying funcs.

Value

The extracted data, either as an ohvbd.data.frame or ohvbd.ad.matrix object.

Author(s)

Francis Windram

Examples


search_hub("Ixodes", "vt") |>
  fetch() |>
  glean() |>
  fetch_citations()


ohvbd documentation built on March 10, 2026, 1:07 a.m.