fetch_citations_vd: Retrieve citations for vecdyn data

View source: R/fetch_citations.R

fetch_citations_vdR Documentation

Retrieve citations for vecdyn data

Description

Retrieve citations for vecdyn data either directly from the dataset or by redownloading the appropriate data.

Usage

fetch_citations_vd(
  dataset,
  redownload = TRUE,
  minimise = FALSE,
  collapse_cols = TRUE
)

Arguments

dataset

The dataset from which you wish to retrieve citations.

redownload

Redownload data if citation columns are missing.

minimise

Whether to return one row per citation (rather than one per dataset ID).

collapse_cols

Whether to remove completely empty columns.

Value

ohvbd.data.frame of citation data

Author(s)

Francis Windram


ohvbd documentation built on March 10, 2026, 1:07 a.m.