fetch_citations_vt: Retrieve citations for vectraits data

View source: R/fetch_citations.R

fetch_citations_vtR Documentation

Retrieve citations for vectraits data

Description

Retrieve citations for vectraits data either directly from the dataset or by redownloading the appropriate data.

Usage

fetch_citations_vt(dataset, redownload = TRUE, minimise = FALSE)

Arguments

dataset

The dataset from which you wish to retrieve citations.

redownload

Redownload data if citation columns are missing.

minimise

Whether to return one row per citation (rather than one per dataset ID).

Value

ohvbd.data.frame of citation data

Author(s)

Francis Windram


ohvbd documentation built on March 10, 2026, 1:07 a.m.