| fetch_gbif | R Documentation |
Retrieve GBIF dataset/s specified by their dataset ID.
fetch_gbif(ids, filepath = ".")
ids |
a string or character vector of ids (preferably in an |
filepath |
directory to save gbif download files into. |
A list of rgbif occ_download_get objects, as an ohvbd.responses object.
Only 300 datasets can be requested at once (for now) due to technical limitations originating from the GBIF server setup. It is worth splitting longer lists of ids into a couple of chunks if you need more than this.
If you regularly use ohvbd to download large numbers of datasets at once and chunking is causing you other issues, please raise an issue at https://github.com/fwimp/ohvbd/issues.
Francis Windram
fetch_gbif("dbc4a3ae-680f-44e6-ab25-c70e27b38dbc")
ohvbd.ids("dbc4a3ae-680f-44e6-ab25-c70e27b38dbc", "gbif") |>
fetch() # Calls fetch_gbif()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.