fetch_vd: Fetch VecDyn dataset/s by ID

View source: R/fetch_vd.R

fetch_vdR Documentation

Fetch VecDyn dataset/s by ID

Description

Retrieve VecDyn dataset/s specified by their dataset ID.

Usage

fetch_vd(ids, rate = 5, connections = 2, basereq = vb_basereq())

Arguments

ids

a numeric ID or numeric vector of ids (preferably in an ohvbd.ids object) indicating the particular dataset/s to download.

rate

maximum number of calls to the API per second.

connections

number of simultaneous connections to the server at once. Maximum 8. Do not enable unless you really need to as this hits the server significantly harder than usual.

basereq

an httr2 request object, as generated by vb_basereq(). If NA, uses the default request.

Value

A list of httr2 response objects, as an ohvbd.responses object.

Author(s)

Francis Windram

Examples


fetch_vd(54)

fetch_vd(c(423,424,425))

ohvbd.ids(c(423,424,425), "vd") |>
  fetch() # Calls fetch_vd()


ohvbd documentation built on March 10, 2026, 1:07 a.m.