View source: R/fetch_vd_meta.R
| fetch_vd_counts | R Documentation |
Retrieve length of VecDyn dataset/s specified by their dataset ID.
fetch_vd_counts(
ids,
page_size = 50,
cache_location = NULL,
refresh_cache = FALSE,
noprogress = FALSE,
basereq = vb_basereq()
)
ids |
a numeric ID or numeric vector of ids (preferably in an |
page_size |
the page size returned by VecDyn (default is 50). |
cache_location |
path to cache location (defaults to a temporary user directory, or one set by |
refresh_cache |
force a refresh of the relevant cached data. |
noprogress |
disable non-essential messaging (progress bars etc.). |
basereq |
an httr2 request object, as generated by |
A dataframe describing the number of rows and number of pages for the set of ids.
Francis Windram
fetch_vd_counts(54)
fetch_vd_counts(c(423,424,425))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.