fetch_vt: Fetch VecTraits dataset/s by ID

View source: R/fetch_vt.R

fetch_vtR Documentation

Fetch VecTraits dataset/s by ID

Description

Retrieve VecTraits dataset/s specified by their dataset ID.

Usage

fetch_vt(ids, rate = 5, connections = 2, basereq = vb_basereq())

Arguments

ids

a numeric ID or numeric vector of ids (preferably in an ohvbd.ids object) indicating the particular dataset/s to download.

rate

maximum number of calls to the API per second.

connections

number of simultaneous connections to the server at once. Maximum 8. Do not enable unless you really need to as this hits the server significantly harder than usual.

basereq

an httr2 request object, as generated by vb_basereq(). If NA, uses the default request.

Value

A list of httr2 response objects, as an ohvbd.responses object.

Author(s)

Francis Windram

Examples


fetch_vt(54)

fetch_vt(c(54, 55, 56))

ohvbd.ids(c(54, 55, 56), "vt") |>
  fetch() # Calls fetch_vt()


ohvbd documentation built on March 10, 2026, 1:07 a.m.