find_vb_404s: Find the ids of any resps that contain 404 errors from a list...

View source: R/utils.R

find_vb_404sR Documentation

Find the ids of any resps that contain 404 errors from a list of them

Description

Find the ids of any resps that contain 404 errors from a list of them

Usage

find_vb_404s(l)

Arguments

l

A list of httr2 error objects.

Value

the ids from those found objects.


ohvbd documentation built on March 10, 2026, 1:07 a.m.