find_vd_missing: Find the ids of any resps that contain a count of 0 list of...

View source: R/utils.R

find_vd_missingR Documentation

Find the ids of any resps that contain a count of 0 list of them

Description

Find the ids of any resps that contain a count of 0 list of them

Usage

find_vd_missing(l)

Arguments

l

A list of httr2 error objects.

Value

the ids from those found objects.


ohvbd documentation built on March 10, 2026, 1:07 a.m.