force_db: Force an object to appear to come from a specific database

View source: R/utils.R

force_dbR Documentation

Force an object to appear to come from a specific database

Description

Force an object to appear to come from a specific database

Usage

force_db(x, db)

Arguments

x

Object to force.

db

Database to apply to x.

Value

Object with the "db" attribute set to db

Note

DO NOT use this function to create ids to feed into fetch()!

Objects created in this way may lack vital underlying data required later. Instead use ohvbd.ids() for this purpose.

This is a synonym for ohvbd_db(x) <- db that's easier to work with in pipelines.

Author(s)

Francis Windram

See Also

Internal attributes

Examples

force_db(c(1,2,3), "vt")


ohvbd documentation built on March 10, 2026, 1:07 a.m.