glean: Extract specified data from a set of responses

View source: R/class_methods.R

gleanR Documentation

Extract specified data from a set of responses

Description

This is a convenience method that infers and applies the correct extractor for the input

Usage

glean(res, ...)

Arguments

res

An object of type ohvbd.responses or ohvbd.ad.matrix generated from fetch() and containing data from one of the supported databases.

...

Any arguments to be passed to the underlying extractors (unused).

Value

The extracted data, either as an ohvbd.data.frame or ohvbd.ad.matrix object.

Author(s)

Francis Windram

Examples


search_hub("Ixodes", "vt") |> fetch() |> glean(cols=c("Interactor1Species"))
fetch_ad(use_cache=TRUE) |> glean(targetdate="2020-08-04")


ohvbd documentation built on March 10, 2026, 1:07 a.m.