glean_gbif: Parse data from requests to GBIF

View source: R/glean_gbif.R

glean_gbifR Documentation

Parse data from requests to GBIF

Description

Extract the data returned by a call to fetch_gbif(), filter columns of interest, and find unique rows if required.

Usage

glean_gbif(res, cols = NULL, returnunique = FALSE)

Arguments

res

a list of responses from GBIF as an ohvbd.responses object.

cols

a character vector of columns to extract from the dataset.

returnunique

whether to return only the unique rows within each dataset according to the filtered columns.

Value

An ohvbd.data.frame containing the requested data.

Author(s)

Francis Windram

Examples


fetch_gbif("dbc4a3ae-680f-44e6-ab25-c70e27b38dbc") |>
  glean_gbif()

ohvbd.ids("dbc4a3ae-680f-44e6-ab25-c70e27b38dbc", "gbif") |>
  fetch() |>
  glean() # Calls glean_gbif()


ohvbd documentation built on March 10, 2026, 1:07 a.m.