glean_vt: Parse data from requests to VecTraits

View source: R/glean_vt.R

glean_vtR Documentation

Parse data from requests to VecTraits

Description

Extract the data returned by a call to fetch_vt(), filter columns of interest, and find unique rows if required.

Usage

glean_vt(res, cols = NULL, returnunique = FALSE)

Arguments

res

a list of responses from VecTraits as an ohvbd.responses object.

cols

a character vector of columns to extract from the dataset.

returnunique

whether to return only the unique rows within each dataset according to the filtered columns.

Value

An ohvbd.data.frame containing the requested data.

Author(s)

Francis Windram

Examples


fetch_vt(54) |>
  glean_vt(cols=c("DatasetID",
                    "Interactor1Genus",
                    "Interactor1Species"),
             returnunique=TRUE)

ohvbd.ids(54, "vt") |>
  fetch() |>
  glean() # Calls glean_vt()


ohvbd documentation built on March 10, 2026, 1:07 a.m.