has_db: Test whether an object has provenance information

View source: R/class_methods.R

has_dbR Documentation

Test whether an object has provenance information

Description

This function tests whether an object has the provenance information expected by ohvbd.

Usage

has_db(x, ...)

Arguments

x

An object to test.

...

Any arguments to be passed to the underlying functions (unused).

Value

Whether the data has a provenance tag (as a boolean).

Author(s)

Francis Windram

Examples

ids <- ohvbd.ids(c(1,2,3), "vd")
has_db(ids)


ohvbd documentation built on March 10, 2026, 1:07 a.m.