is_cached: Check whether an object has been loaded from cache by ohvbd

View source: R/utils-cache.R

is_cachedR Documentation

Check whether an object has been loaded from cache by ohvbd

Description

Check whether an object has been loaded from cache by ohvbd

Usage

is_cached(x)

Arguments

x

The object to check.

Value

A boolean indicating whether an object has been loaded from the cache.

Author(s)

Francis Windram

Examples


is.cached(c(1,2,3))


ohvbd documentation built on March 10, 2026, 1:07 a.m.