is_from: Test whether an object is considered to be from a particular...

View source: R/class_methods.R

is_fromR Documentation

Test whether an object is considered to be from a particular database

Description

This function tests whether an object is considered (by ohvbd) to be from a given database.

This is a fairly coarse check, and so cannot "work out" data provenance from its structure.

Usage

is_from(x, db, ...)

Arguments

x

An object to test.

db

The database to test against.

...

Any arguments to be passed to the underlying functions (unused).

Value

Whether the data is from a given database (as a boolean).

Author(s)

Francis Windram

Examples

ids <- ohvbd.ids(c(1,2,3), "vd")
is_from(ids, "vd")


ohvbd documentation built on March 10, 2026, 1:07 a.m.