View source: R/utils-validation.R
| match_species | R Documentation |
Match species names to their GBIF backbone ids using rgbif::name_backbone_checklist().
match_species(speciesnames, exact = FALSE, returnids = TRUE, omit = TRUE)
speciesnames |
a vector of species names to match to the GBIF backbone. |
exact |
whether to only return exact species matches. |
returnids |
return the GBIF taxon ids only (otherwise return the full lookup dataframe). |
omit |
omit missing taxon ids (inactive when |
The GBIF taxonids associated with speciesnames or the full GBIF lookup dataframe if returnids = TRUE.
If exact = TRUE and you search for a genus name, this will not be returned.
If you want more control over id filtering, use returnids = FALSE to get the source dataframe.
Francis Windram
match_species(c("Araneus diadematus", "Aedes aegypti"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.