| ohvbd.ids | R Documentation |
When retrieving data from previous searches (or saved lists of IDs), it can be useful to package these data up in the form that ohvbd would expect to come out of a search.
To do this, create an ohvbd.ids object, specifying the database that the ids refer to.
ohvbd.ids(ids, db)
ids |
A numeric vector of ids referring to datasets within the specified database. |
db |
A string specifying the database that these ids refer to. |
An id vector: an S3 vector with class ohvbd.ids.
Francis Windram
ohvbd.ids(c(1,2,3,4,5), db="vt")
ohvbd.ids(c(1,2,3,4,5), db="vd")
ohvbd.ids(
c(
"dbc4a3ae-680f-44e6-ab25-c70e27b38dbc",
"fac87892-68c8-444a-9ae9-46273fdff724"
),
db="gbif"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.