ohvbd_dryrun: Option: dry runs of ohvbd searches

ohvbd_dryrunR Documentation

Option: dry runs of ohvbd searches

Description

Set this option to make ohvbd terminate searches before execution and return the request object instead.

Note

This is usually only useful when debugging, testing, or developing ohvbd.

Author(s)

Francis Windram

Examples


options(ohvbd_dryrun = TRUE)
search_hub("Ixodes ricinus")

options(ohvbd_dryrun = NULL)  # Unset dryrun


ohvbd documentation built on March 10, 2026, 1:07 a.m.