search_vt: Search VecTraits by keyword

View source: R/search_vt.R

search_vtR Documentation

Search VecTraits by keyword

Description

Retrieve the IDs for any VecTraits datasets matching the given keywords.

Usage

search_vt(keywords, basereq = vb_basereq())

Arguments

keywords

either a string of search terms separated by spaces, or a vector of keywords.

basereq

an httr2 request object, as generated by vb_basereq(). If NA, uses the default request.

Value

An ohvbd.ids vector of VecTraits dataset IDs.

Warning

The ids returned from the server (and thus this function) do not necessarily precisely match the keywords that were requested.

For example search_vt("United Kingdom") does not return only items found in the United Kingdom. Instead it returns items where some part of the string "United Kingdom" appears in one of the indexed columns.

The indexed columns of VecTraits are:

  • DatasetID

  • OriginalTraitName

  • Variables

  • Interactor1Order

  • Interactor1Family

  • Interactor1Genus

  • Interactor1Species

  • Interactor1Stage

  • Interactor1Sex

  • Interactor2Genus

  • Interactor2Species

  • Citation

  • DOI

  • CuratedByDOI

  • SubmittedBy

Note

search_hub() is now preferred for keyword searches:

# old style
search_vt(c("Ixodes", "ricinus")

# new style
search_hub("Ixodes ricinus", db = "vt")

search_vt() may be deprecated in the future.

Author(s)

Francis Windram

Examples


search_vt("Aedes aegypti")

search_vt(c("Aedes", "aegypti"))


ohvbd documentation built on March 10, 2026, 1:07 a.m.