set_default_ohvbd_cache: Set the default ohvbd cache location

View source: R/utils-cache.R

set_default_ohvbd_cacheR Documentation

Set the default ohvbd cache location

Description

Set the default ohvbd cache location

Usage

set_default_ohvbd_cache(d = NULL)

Arguments

d

The directory to set the cache path to (or NULL to use a default location).

Value

The path of the cache (invisibly)

Note

To permanently set a path to use, add the following to your .Rprofile file:

options(ohvbd_cache = "path/to/directory")

Where path/to/directory is the directory in which you wish to cache ohvbd files.

You can find a good default path by running set_default_ohvbd_cache() with no arguments.

Author(s)

Francis Windram

Examples

set_default_ohvbd_cache()


ohvbd documentation built on March 10, 2026, 1:07 a.m.