| set_ohvbd_compat | R Documentation |
Set ohvbd to disable ssl verification for calls to external APIs. This should not be needed (and not be performed) unless you are otherwise experiencing SSL issues when using the package!
When in interactive mode, checks with you to make sure you want to do this. Does not check when run in a script.
set_ohvbd_compat(value = TRUE)
value |
The boolean value to set ohvbd_compat to. |
No return value, called for side effects
Francis Windram
set_ohvbd_compat()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.