space_collapse: collapse a list of character strings to a JS space-separated...

View source: R/utils.R

space_collapseR Documentation

collapse a list of character strings to a JS space-separated single string

Description

collapse a list of character strings to a JS space-separated single string

Usage

space_collapse(v)

Arguments

v

a vector to format.

Value

collapsed string.


ohvbd documentation built on March 10, 2026, 1:07 a.m.