| vb_basereq | R Documentation |
This request is used as the basis for all calls to the vectorbyte API. It does not contain any tokens or session ids, and thus can be regenerated at any time.
vb_basereq(
baseurl = "https://vectorbyte.crc.nd.edu/portal/api/",
useragent = "ROHVBD",
unsafe = FALSE,
.qa = FALSE
)
baseurl |
the base url for the vectorbyte API. |
useragent |
the user agent string used when contacting vectorbyte. |
unsafe |
disable ssl verification (shouldn't ever be required unless you are otherwise experiencing SSL issues!) |
.qa |
switch to the vb qa server (only useful for testing). |
Returns an httr2 request object, pointing at baseurl using useragent.
Francis Windram
basereq <- vb_basereq(
baseurl="https://vectorbyte.crc.nd.edu/portal/api/",
useragent="ROHVBD")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.