| vd_make_req | R Documentation |
Create a query for a given VD id at a given page
vd_make_req(id, pagenum, rate, url = "", useragent = "", unsafe = FALSE)
id |
ID of the vecdyn dataset. |
pagenum |
page to retrieve. |
rate |
rate limit for requests. |
url |
the base url for the vectorbyte API. |
useragent |
the user agent string used when contacting vectorbyte. |
unsafe |
disable ssl verification (should only ever be required on Linux, do not enable this by default). |
httr2 request containing the requisite call to retrieve the data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.