| ad_basereq | R Documentation |
This string is used as the basis for all calls to AREAdata. It does not contain any tokens or session ids, and thus can be regenerated at any time.
ad_basereq()
Returns a string containing the root address of the AREAdata dataset.
Francis Windram
basereq <- ad_basereq()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.