Learn R Programming

ohvbd (version 1.0.0)

ad_basereq: Generate a base request string for the AREAdata database

Description

This string is used as the basis for all calls to AREAdata. It does not contain any tokens or session ids, and thus can be regenerated at any time.

Usage

ad_basereq()

Arguments

Value

Returns a string containing the root address of the AREAdata dataset.

Author

Francis Windram

Examples

Run this code
basereq <- ad_basereq()

Run the code above in your browser using DataLab