Learn R Programming

ohvbd (version 1.0.0)

coercedate: Try to coerce a date even when bits are missing

Description

Try to coerce a date even when bits are missing

Usage

coercedate(dates, return_iso = FALSE, nulliferror = FALSE)

Value

Coerced dates.

Arguments

dates

The date/s to try and coerce.