View source: R/ohvbd-deprecated.R
| extract | R Documentation |
This is a convenience method that infers and applies the correct extractor for the input.
extract(res, ...)
res |
An object of type |
... |
Any arguments to be passed to the underlying extractors (see |
The extracted data, either as an ohvbd.data.frame or ohvbd.ad.matrix object.
extract() is now deprecated and should not be used. Please use glean() instead.
Francis Windram
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.