This is a convenience method that infers and applies the correct extractor for the input.
extract(res, ...)The extracted data, either as an ohvbd.data.frame or ohvbd.ad.matrix object.
An object of type ohvbd.responses or ohvbd.ad.matrix generated from fetch()
and containing data from one of the supported databases.
Any arguments to be passed to the underlying extractors (see glean_vt() and glean_ad() for specific arguments).
Francis Windram