Learn R Programming

ohvbd (version 1.0.0)

fetch: Fetch specified data from a set of ids

Description

This is a convenience method that infers and applies the correct fetch function for the input ids.

Usage

fetch(ids, ...)

Value

The downloaded data, as an ohvbd.responses object.

Arguments

ids

An object of type ohvbd.ids (generated from a search, manually packaged using ohvbd.ids() or generated by another function).

...

Any other arguments to be passed to the underlying fetch functions (see fetch_vt() and fetch_vd() for specific arguments).

Author

Francis Windram

Examples

Run this code
if (FALSE) { # interactive()
search_hub("Ixodes", "vt") |> fetch()
}

Run the code above in your browser using DataLab