powered by
This is a convenience method that infers and applies the correct fetch function for the input ids.
fetch(ids, ...)
The downloaded data, as an ohvbd.responses object.
ohvbd.responses
An object of type ohvbd.ids (generated from a search, manually packaged using ohvbd.ids() or generated by another function).
ohvbd.ids
ohvbd.ids()
Any other arguments to be passed to the underlying fetch functions (see fetch_vt() and fetch_vd() for specific arguments).
fetch_vt()
fetch_vd()
Francis Windram
if (FALSE) { # interactive() search_hub("Ixodes", "vt") |> fetch() }
Run the code above in your browser using DataLab