View source: R/class_methods.R
| fetch_citations | R Documentation |
This tries to extract and simplify the citations from a dataset downloaded using ohvbd.
fetch_citations(dataset, ...)
dataset |
An object of type |
... |
Any arguments to be passed to the underlying funcs. |
The extracted data, either as an ohvbd.data.frame or ohvbd.ad.matrix object.
Francis Windram
search_hub("Ixodes", "vt") |>
fetch() |>
glean() |>
fetch_citations()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.