Learn R Programming

ohvbd (version 1.0.0)

fetch_citations: Try to find the relevant citations for a dataset

Description

This tries to extract and simplify the citations from a dataset downloaded using ohvbd.

Usage

fetch_citations(dataset, ...)

Value

The extracted data, either as an ohvbd.data.frame or ohvbd.ad.matrix object.

Arguments

dataset

An object of type ohvbd.data.frame (generated from glean(), preferred) or of type ohvbd.ids and containing data from one of the supported databases.

...

Any arguments to be passed to the underlying funcs.

Author

Francis Windram

Examples

Run this code
if (FALSE) { # interactive()
search_hub("Ixodes", "vt") |>
  fetch() |>
  glean() |>
  fetch_citations()
}

Run the code above in your browser using DataLab