powered by
This tries to extract and simplify the citations from a dataset downloaded using ohvbd.
ohvbd
fetch_citations(dataset, ...)
The extracted data, either as an ohvbd.data.frame or ohvbd.ad.matrix object.
ohvbd.data.frame
ohvbd.ad.matrix
An object of type ohvbd.data.frame (generated from glean(), preferred) or of type ohvbd.ids and containing data from one of the supported databases.
glean()
ohvbd.ids
Any arguments to be passed to the underlying funcs.
Francis Windram
if (FALSE) { # interactive() search_hub("Ixodes", "vt") |> fetch() |> glean() |> fetch_citations() }
Run the code above in your browser using DataLab