Learn R Programming

ohvbd (version 1.0.0)

fetch_citations_vd: Retrieve citations for vecdyn data

Description

Retrieve citations for vecdyn data either directly from the dataset or by redownloading the appropriate data.

Usage

fetch_citations_vd(
  dataset,
  redownload = TRUE,
  minimise = FALSE,
  collapse_cols = TRUE
)

Value

ohvbd.data.frame of citation data

Arguments

dataset

The dataset from which you wish to retrieve citations.

redownload

Redownload data if citation columns are missing.

minimise

Whether to return one row per citation (rather than one per dataset ID).

collapse_cols

Whether to remove completely empty columns.

Author

Francis Windram