View source: R/fetch_citations.R
| fetch_citations_vt | R Documentation |
Retrieve citations for vectraits data either directly from the dataset or by redownloading the appropriate data.
fetch_citations_vt(dataset, redownload = TRUE, minimise = FALSE)
dataset |
The dataset from which you wish to retrieve citations. |
redownload |
Redownload data if citation columns are missing. |
minimise |
Whether to return one row per citation (rather than one per dataset ID). |
ohvbd.data.frame of citation data
Francis Windram
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.