Retrieve citations for vectraits data either directly from the dataset or by redownloading the appropriate data.
fetch_citations_vt(dataset, redownload = TRUE, minimise = FALSE)ohvbd.data.frame of citation data
The dataset from which you wish to retrieve citations.
Redownload data if citation columns are missing.
Whether to return one row per citation (rather than one per dataset ID).
Francis Windram