View source: R/fetch_gadm_sfs.R
| fetch_gadm_sfs | R Documentation |
Retrieve AREAdata gadm mapping shapefiles specified by spatial scale (GID). These vectors are cached as GeoPackage files.
fetch_gadm_sfs(
gid = 0,
cache_location = NULL,
refresh_cache = FALSE,
basereq = ad_basereq(),
call = rlang::caller_env()
)
gid |
the spatial scale to retrieve (0 = country-level, 1=province-level...). |
cache_location |
path to cache location (defaults to a temporary user directory, or one set by |
refresh_cache |
force a refresh of the relevant cached data. |
basereq |
the url of the AREAdata database (usually generated by |
call |
The env from which this was called (defaults to the direct calling environment). |
A SpatVector (from terra::vect()) of the requested shapefile.
Francis Windram
fetch_gadm_sfs(gid=0)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.