| fetch_vd | R Documentation |
Retrieve VecDyn dataset/s specified by their dataset ID.
fetch_vd(ids, rate = 5, connections = 2, basereq = vb_basereq())
ids |
a numeric ID or numeric vector of ids (preferably in an |
rate |
maximum number of calls to the API per second. |
connections |
number of simultaneous connections to the server at once. Maximum 8. Do not enable unless you really need to as this hits the server significantly harder than usual. |
basereq |
an httr2 request object, as generated by |
A list of httr2 response objects, as an ohvbd.responses object.
Francis Windram
fetch_vd(54)
fetch_vd(c(423,424,425))
ohvbd.ids(c(423,424,425), "vd") |>
fetch() # Calls fetch_vd()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.