A list of httr2 response objects, as an ohvbd.responses object.
Arguments
ids
a numeric ID or numeric vector of ids (preferably in an ohvbd.ids object) indicating the particular dataset/s to download.
rate
maximum number of calls to the API per second.
connections
number of simultaneous connections to the server at once. Maximum 8. Do not enable unless you really need to as this hits the server significantly harder than usual.
basereq
an httr2 request object, as generated by vb_basereq(). If NA, uses the default request.