powered by
Retrieve length of VecDyn dataset/s specified by their dataset ID.
fetch_vd_counts( ids, page_size = 50, cache_location = NULL, refresh_cache = FALSE, noprogress = FALSE, basereq = vb_basereq() )
A dataframe describing the number of rows and number of pages for the set of ids.
a numeric ID or numeric vector of ids (preferably in an ohvbd.ids object) indicating the particular dataset/s to download.
ohvbd.ids
the page size returned by VecDyn (default is 50).
path to cache location (defaults to a temporary user directory, or one set by set_default_ohvbd_cache()).
set_default_ohvbd_cache()
force a refresh of the relevant cached data.
disable non-essential messaging (progress bars etc.).
an httr2 request object, as generated by vb_basereq(). If NA, uses the default request.
vb_basereq()
NA
Francis Windram
if (FALSE) { # interactive() fetch_vd_counts(54) fetch_vd_counts(c(423,424,425)) }
Run the code above in your browser using DataLab