| fetch_vt | R Documentation |
Retrieve VecTraits dataset/s specified by their dataset ID.
fetch_vt(ids, rate = 5, connections = 2, basereq = vb_basereq())
ids |
a numeric ID or numeric vector of ids (preferably in an |
rate |
maximum number of calls to the API per second. |
connections |
number of simultaneous connections to the server at once. Maximum 8. Do not enable unless you really need to as this hits the server significantly harder than usual. |
basereq |
an httr2 request object, as generated by |
A list of httr2 response objects, as an ohvbd.responses object.
Francis Windram
fetch_vt(54)
fetch_vt(c(54, 55, 56))
ohvbd.ids(c(54, 55, 56), "vt") |>
fetch() # Calls fetch_vt()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.