Learn R Programming

ohvbd (version 1.0.0)

find_vb_404s: Find the ids of any resps that contain 404 errors from a list of them

Description

Find the ids of any resps that contain 404 errors from a list of them

Usage

find_vb_404s(l)

Value

the ids from those found objects.

Arguments

l

A list of httr2 error objects.