| force_db | R Documentation |
Force an object to appear to come from a specific database
force_db(x, db)
x |
Object to force. |
db |
Database to apply to |
Object with the "db" attribute set to db
DO NOT use this function to create ids to feed into fetch()!
Objects created in this way may lack vital underlying data required later.
Instead use ohvbd.ids() for this purpose.
This is a synonym for ohvbd_db(x) <- db that's easier to work with in pipelines.
Francis Windram
Internal attributes
force_db(c(1,2,3), "vt")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.