Learn R Programming

ohvbd (version 1.0.0)

force_db: Force an object to appear to come from a specific database

Description

Force an object to appear to come from a specific database

Usage

force_db(x, db)

Value

Object with the "db" attribute set to db

Arguments

x

Object to force.

db

Database to apply to x.

Author

Francis Windram

See Also

Internal attributes

Examples

Run this code
force_db(c(1,2,3), "vt")

Run the code above in your browser using DataLab