format_time_overlap_bar: Format and print date overlaps
Description
Format and output to the terminal a visualisation of the overlaps between a given period and another set of dates.
This is mostly used in the error handling of glean_ad() however it can also be used independently.
It was designed to fill a more general role within UI design using the cli package, and should be usable (or hackable) by others needing the same tool.