generate_vt_template: Generate a vectraits template from a short set of survey responses
Description
Given the large number of fields in vectraits it can be hard to
know which of these you need to fill out. This generator asks a series of
questions to determine what columns should be included in one's dataset.
Usage
generate_vt_template()
Arguments
Value
A character vector containing the column headers of the desired vectraits template or NULL.