View source: R/class_methods.R
| glean | R Documentation |
This is a convenience method that infers and applies the correct extractor for the input
glean(res, ...)
res |
An object of type |
... |
Any arguments to be passed to the underlying extractors (unused). |
The extracted data, either as an ohvbd.data.frame or ohvbd.ad.matrix object.
Francis Windram
search_hub("Ixodes", "vt") |> fetch() |> glean(cols=c("Interactor1Species"))
fetch_ad(use_cache=TRUE) |> glean(targetdate="2020-08-04")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.