Learn R Programming

ohvbd (version 1.0.0)

glean: Extract specified data from a set of responses

Description

This is a convenience method that infers and applies the correct extractor for the input

Usage

glean(res, ...)

Value

The extracted data, either as an ohvbd.data.frame or ohvbd.ad.matrix object.

Arguments

res

An object of type ohvbd.responses or ohvbd.ad.matrix generated from fetch() and containing data from one of the supported databases.

...

Any arguments to be passed to the underlying extractors (unused).

Author

Francis Windram

Examples

Run this code
if (FALSE) { # interactive()
search_hub("Ixodes", "vt") |> fetch() |> glean(cols=c("Interactor1Species"))
fetch_ad(use_cache=TRUE) |> glean(targetdate="2020-08-04")
}

Run the code above in your browser using DataLab