powered by
This is a convenience method that infers and applies the correct extractor for the input
glean(res, ...)
The extracted data, either as an ohvbd.data.frame or ohvbd.ad.matrix object.
ohvbd.data.frame
ohvbd.ad.matrix
An object of type ohvbd.responses or ohvbd.ad.matrix generated from fetch() and containing data from one of the supported databases.
ohvbd.responses
fetch()
Any arguments to be passed to the underlying extractors (unused).
Francis Windram
if (FALSE) { # interactive() search_hub("Ixodes", "vt") |> fetch() |> glean(cols=c("Interactor1Species")) fetch_ad(use_cache=TRUE) |> glean(targetdate="2020-08-04") }
Run the code above in your browser using DataLab