| glean_gbif | R Documentation |
Extract the data returned by a call to fetch_gbif(), filter columns of interest, and find unique rows if required.
glean_gbif(res, cols = NULL, returnunique = FALSE)
res |
a list of responses from GBIF as an |
cols |
a character vector of columns to extract from the dataset. |
returnunique |
whether to return only the unique rows within each dataset according to the filtered columns. |
An ohvbd.data.frame containing the requested data.
Francis Windram
fetch_gbif("dbc4a3ae-680f-44e6-ab25-c70e27b38dbc") |>
glean_gbif()
ohvbd.ids("dbc4a3ae-680f-44e6-ab25-c70e27b38dbc", "gbif") |>
fetch() |>
glean() # Calls glean_gbif()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.