Learn R Programming

ohvbd (version 1.0.0)

glean_gbif: Parse data from requests to GBIF

Description

Extract the data returned by a call to fetch_gbif(), filter columns of interest, and find unique rows if required.

Usage

glean_gbif(res, cols = NULL, returnunique = FALSE)

Value

An ohvbd.data.frame containing the requested data.

Arguments

res

a list of responses from GBIF as an ohvbd.responses object.

cols

a character vector of columns to extract from the dataset.

returnunique

whether to return only the unique rows within each dataset according to the filtered columns.

Author

Francis Windram

Examples

Run this code
if (FALSE) { # interactive()
fetch_gbif("dbc4a3ae-680f-44e6-ab25-c70e27b38dbc") |>
  glean_gbif()

ohvbd.ids("dbc4a3ae-680f-44e6-ab25-c70e27b38dbc", "gbif") |>
  fetch() |>
  glean() # Calls glean_gbif()
}

Run the code above in your browser using DataLab