| glean_vd | R Documentation |
Extract the data returned by a call to fetch_vd(), filter columns of interest, and find unique rows if required.
glean_vd(res, cols = NULL, returnunique = FALSE)
res |
a list of responses from VecDyn as an |
cols |
a character vector of columns to extract from the dataset. If specified, this will be adjusted to always include the "dataset_id" column. |
returnunique |
whether to return only the unique rows within each dataset according to the filtered columns. |
An ohvbd.data.frame containing the requested data.
Francis Windram
fetch_vd(247) |>
glean_vd(cols=c("species",
"sample_start_date",
"sample_value"),
returnunique=TRUE)
ohvbd.ids(247, "vd") |>
fetch() |>
glean() # Calls glean_vd()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.