| glean_vt | R Documentation |
Extract the data returned by a call to fetch_vt(), filter columns of interest, and find unique rows if required.
glean_vt(res, cols = NULL, returnunique = FALSE)
res |
a list of responses from VecTraits as an |
cols |
a character vector of columns to extract from the dataset. |
returnunique |
whether to return only the unique rows within each dataset according to the filtered columns. |
An ohvbd.data.frame containing the requested data.
Francis Windram
fetch_vt(54) |>
glean_vt(cols=c("DatasetID",
"Interactor1Genus",
"Interactor1Species"),
returnunique=TRUE)
ohvbd.ids(54, "vt") |>
fetch() |>
glean() # Calls glean_vt()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.