Learn R Programming

ohvbd (version 1.0.0)

glean_vt: Parse data from requests to VecTraits

Description

Extract the data returned by a call to fetch_vt(), filter columns of interest, and find unique rows if required.

Usage

glean_vt(res, cols = NULL, returnunique = FALSE)

Value

An ohvbd.data.frame containing the requested data.

Arguments

res

a list of responses from VecTraits as an ohvbd.responses object.

cols

a character vector of columns to extract from the dataset.

returnunique

whether to return only the unique rows within each dataset according to the filtered columns.

Author

Francis Windram

Examples

Run this code
if (FALSE) { # interactive()
fetch_vt(54) |>
  glean_vt(cols=c("DatasetID",
                    "Interactor1Genus",
                    "Interactor1Species"),
             returnunique=TRUE)

ohvbd.ids(54, "vt") |>
  fetch() |>
  glean() # Calls glean_vt()
}

Run the code above in your browser using DataLab