View source: R/class_methods.R
| has_db | R Documentation |
This function tests whether an object has the provenance information expected by ohvbd.
has_db(x, ...)
x |
An object to test. |
... |
Any arguments to be passed to the underlying functions (unused). |
Whether the data has a provenance tag (as a boolean).
Francis Windram
ids <- ohvbd.ids(c(1,2,3), "vd")
has_db(ids)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.