Learn R Programming

ohvbd (version 1.0.0)

has_db: Test whether an object has provenance information

Description

This function tests whether an object has the provenance information expected by ohvbd.

Usage

has_db(x, ...)

Value

Whether the data has a provenance tag (as a boolean).

Arguments

x

An object to test.

...

Any arguments to be passed to the underlying functions (unused).

Author

Francis Windram

Examples

Run this code
ids <- ohvbd.ids(c(1,2,3), "vd")
has_db(ids)

Run the code above in your browser using DataLab