powered by
This function tests whether an object has the provenance information expected by ohvbd.
ohvbd
has_db(x, ...)
Whether the data has a provenance tag (as a boolean).
An object to test.
Any arguments to be passed to the underlying functions (unused).
Francis Windram
ids <- ohvbd.ids(c(1,2,3), "vd") has_db(ids)
Run the code above in your browser using DataLab