| is_cached | R Documentation |
Check whether an object has been loaded from cache by ohvbd
is_cached(x)
x |
The object to check. |
A boolean indicating whether an object has been loaded from the cache.
Francis Windram
is.cached(c(1,2,3))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.