Learn R Programming

ohvbd (version 1.0.0)

is_cached: Check whether an object has been loaded from cache by ohvbd

Description

Check whether an object has been loaded from cache by ohvbd

Usage

is_cached(x)

Value

A boolean indicating whether an object has been loaded from the cache.

Arguments

x

The object to check.

Author

Francis Windram

Examples

Run this code
if (FALSE) { # interactive()
is.cached(c(1,2,3))
}

Run the code above in your browser using DataLab