powered by
Check whether an object has been loaded from cache by ohvbd
is_cached(x)
A boolean indicating whether an object has been loaded from the cache.
The object to check.
Francis Windram
if (FALSE) { # interactive() is.cached(c(1,2,3)) }
Run the code above in your browser using DataLab