View source: R/class_methods.R
| is_from | R Documentation |
This function tests whether an object is considered (by ohvbd) to be from a given database.
This is a fairly coarse check, and so cannot "work out" data provenance from its structure.
is_from(x, db, ...)
x |
An object to test. |
db |
The database to test against. |
... |
Any arguments to be passed to the underlying functions (unused). |
Whether the data is from a given database (as a boolean).
Francis Windram
ids <- ohvbd.ids(c(1,2,3), "vd")
is_from(ids, "vd")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.