Learn R Programming

ohvbd (version 1.0.0)

is_from: Test whether an object is considered to be from a particular database

Description

This function tests whether an object is considered (by ohvbd) to be from a given database.

This is a fairly coarse check, and so cannot "work out" data provenance from its structure.

Usage

is_from(x, db, ...)

Value

Whether the data is from a given database (as a boolean).

Arguments

x

An object to test.

db

The database to test against.

...

Any arguments to be passed to the underlying functions (unused).

Author

Francis Windram

Examples

Run this code
ids <- ohvbd.ids(c(1,2,3), "vd")
is_from(ids, "vd")

Run the code above in your browser using DataLab