powered by
This function tests whether an object is considered (by ohvbd) to be from a given database.
ohvbd
This is a fairly coarse check, and so cannot "work out" data provenance from its structure.
is_from(x, db, ...)
Whether the data is from a given database (as a boolean).
An object to test.
The database to test against.
Any arguments to be passed to the underlying functions (unused).
Francis Windram
ids <- ohvbd.ids(c(1,2,3), "vd") is_from(ids, "vd")
Run the code above in your browser using DataLab