Learn R Programming

ohvbd (version 1.0.0)

match_species: Match species names to their GBIF backbone ids

Description

Match species names to their GBIF backbone ids using rgbif::name_backbone_checklist().

Usage

match_species(speciesnames, exact = FALSE, returnids = TRUE, omit = TRUE)

Value

The GBIF taxonids associated with speciesnames or the full GBIF lookup dataframe if returnids = TRUE.

Arguments

speciesnames

a vector of species names to match to the GBIF backbone.

exact

whether to only return exact species matches.

returnids

return the GBIF taxon ids only (otherwise return the full lookup dataframe).

omit

omit missing taxon ids (inactive when returnids = FALSE).

Author

Francis Windram

Examples

Run this code
match_species(c("Araneus diadematus", "Aedes aegypti"))

Run the code above in your browser using DataLab