powered by
Match species names to their GBIF backbone ids using rgbif::name_backbone_checklist().
rgbif::name_backbone_checklist()
match_species(speciesnames, exact = FALSE, returnids = TRUE, omit = TRUE)
The GBIF taxonids associated with speciesnames or the full GBIF lookup dataframe if returnids = TRUE.
speciesnames
returnids = TRUE
a vector of species names to match to the GBIF backbone.
whether to only return exact species matches.
return the GBIF taxon ids only (otherwise return the full lookup dataframe).
omit missing taxon ids (inactive when returnids = FALSE).
returnids = FALSE
Francis Windram
match_species(c("Araneus diadematus", "Aedes aegypti"))
Run the code above in your browser using DataLab