When retrieving data from previous searches (or saved lists of IDs), it can
be useful to package these data up in the form that ohvbd would expect to
come out of a search.
To do this, create an ohvbd.ids object, specifying the database that the ids refer to.
Usage
ohvbd.ids(ids, db)
Value
An id vector: an S3 vector with class ohvbd.ids.
Arguments
ids
A numeric vector of ids referring to datasets within the specified database.
db
A string specifying the database that these ids refer to.