| ohvbd_dryrun | R Documentation |
Set this option to make ohvbd terminate searches before execution and return the request object instead.
This is usually only useful when debugging, testing, or developing ohvbd.
Francis Windram
options(ohvbd_dryrun = TRUE)
search_hub("Ixodes ricinus")
options(ohvbd_dryrun = NULL) # Unset dryrun
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.