| search_hub | R Documentation |
Retrieve the IDs for any datasets matching the given search parameters.
search_hub(
query = "",
db = c("vt", "vd", "gbif", "px"),
fromdate = NULL,
todate = NULL,
locationpoly = NULL,
taxonomy = NULL,
exact = FALSE,
withoutpublished = TRUE,
returnlist = FALSE,
simplify = TRUE,
connections = 8,
base_url = "https://api.vbdhub.org"
)
query |
a search string. |
db |
the databases to search. |
fromdate |
the date from which to search (ISO format: yyyy-mm-dd). |
todate |
the date up to which to search (ISO format: yyyy-mm-dd). |
locationpoly |
a polygon or set of polygons in |
taxonomy |
a numeric vector containing the gbif ids of taxa to search for (found using |
exact |
whether to return exact matches only. |
withoutpublished |
whether to return results without a publishing date when filtering by date. |
returnlist |
return the raw output list rather than a formatted dataframe. |
simplify |
if only a single database was searched, return an |
connections |
the number of connections to use to parallelise queries. |
base_url |
the api URL for vbdhub.org (mostly just for QA testing). |
an ohvbd.hub.search dataframe, an ohvbd.ids vector (if returnlist=TRUE and length(db) == 1) a list (if returnlist=TRUE) containing the search results.
Francis Windram
search_hub("Ixodes ricinus")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.