Retrieve the IDs for any datasets matching the given search parameters.
search_hub(
query = "",
db = c("vt", "vd", "gbif", "px"),
fromdate = NULL,
todate = NULL,
locationpoly = NULL,
taxonomy = NULL,
exact = FALSE,
withoutpublished = TRUE,
returnlist = FALSE,
simplify = TRUE,
connections = 8
)an ohvbd.hub.search dataframe, an ohvbd.ids vector (if returnlist=TRUE and length(db) == 1) a list (if returnlist=TRUE) containing the search results.
a search string.
the databases to search.
the date from which to search (ISO format: yyyy-mm-dd).
the date up to which to search (ISO format: yyyy-mm-dd).
a polygon or set of polygons in terra::SpatVector or WKT MULTIPOLYGON format within which to search. Easily generated using match_countries()
a numeric vector containing the gbif ids of taxa to search for (found using match_species() or similar functions).
whether to return exact matches only.
whether to return results without a publishing date when filtering by date.
return the raw output list rather than a formatted dataframe.
if only a single database was searched, return an ohvbd.ids object instead (defaults to TRUE).
the number of connections to use to parallelise queries.
Francis Windram
if (FALSE) { # interactive()
search_hub("Ixodes ricinus")
}
Run the code above in your browser using DataLab