| search_vt | R Documentation |
Retrieve the IDs for any VecTraits datasets matching the given keywords.
search_vt(keywords, basereq = vb_basereq())
keywords |
either a string of search terms separated by spaces, or a vector of keywords. |
basereq |
an httr2 request object, as generated by |
An ohvbd.ids vector of VecTraits dataset IDs.
The ids returned from the server (and thus this function) do not necessarily precisely match the keywords that were requested.
For example search_vt("United Kingdom") does not return only items found in the United Kingdom. Instead it returns items where some part of the string "United Kingdom" appears in one of the indexed columns.
The indexed columns of VecTraits are:
DatasetID
OriginalTraitName
Variables
Interactor1Order
Interactor1Family
Interactor1Genus
Interactor1Species
Interactor1Stage
Interactor1Sex
Interactor2Genus
Interactor2Species
Citation
DOI
CuratedByDOI
SubmittedBy
search_hub() is now preferred for keyword searches:
# old style
search_vt(c("Ixodes", "ricinus")
# new style
search_hub("Ixodes ricinus", db = "vt")
search_vt() may be deprecated in the future.
Francis Windram
search_vt("Aedes aegypti")
search_vt(c("Aedes", "aegypti"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.