Learn R Programming

ohvbd (version 1.0.0)

search_vt: Search VecTraits by keyword

Description

Retrieve the IDs for any VecTraits datasets matching the given keywords.

Usage

search_vt(keywords, basereq = vb_basereq())

Value

An ohvbd.ids vector of VecTraits dataset IDs.

Arguments

keywords

either a string of search terms separated by spaces, or a vector of keywords.

basereq

an httr2 request object, as generated by vb_basereq(). If NA, uses the default request.

Warning

The ids returned from the server (and thus this function) do not necessarily precisely match the keywords that were requested.

For example search_vt("United Kingdom") does not return only items found in the United Kingdom. Instead it returns items where some part of the string "United Kingdom" appears in one of the indexed columns.

The indexed columns of VecTraits are:

  • DatasetID

  • OriginalTraitName

  • Variables

  • Interactor1Order

  • Interactor1Family

  • Interactor1Genus

  • Interactor1Species

  • Interactor1Stage

  • Interactor1Sex

  • Interactor2Genus

  • Interactor2Species

  • Citation

  • DOI

  • CuratedByDOI

  • SubmittedBy

Author

Francis Windram

Examples

Run this code
if (FALSE) { # interactive()
search_vt("Aedes aegypti")

search_vt(c("Aedes", "aegypti"))
}

Run the code above in your browser using DataLab