| set_default_ohvbd_cache | R Documentation |
Set the default ohvbd cache location
set_default_ohvbd_cache(d = NULL)
d |
The directory to set the cache path to (or NULL to use a default location). |
The path of the cache (invisibly)
To permanently set a path to use, add the following to your .Rprofile file:
options(ohvbd_cache = "path/to/directory")
Where path/to/directory is the directory in which you wish to cache ohvbd files.
You can find a good default path by running set_default_ohvbd_cache() with no arguments.
Francis Windram
set_default_ohvbd_cache()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.