Learn R Programming

ohvbd (version 1.0.0)

space_collapse: collapse a list of character strings to a JS space-separated single string

Description

collapse a list of character strings to a JS space-separated single string

Usage

space_collapse(v)

Value

collapsed string.

Arguments

v

a vector to format.