tee: Tee a pipeline to extract the data at a given point
Description
Add a tee to a pipeline to get the data coming in through the pipe.
This is generally a useful function for debugging pipelines, and for caching
data after expensive calls. It is also useful if you want the flexibility of
multiple calls with the convenience of a fully-piped approach.
The name tee comes from the tee shell command within unix systems.
Usage
tee(x, .name = "teeout", .env = NULL)
Value
The value that came from the left hand side of the pipe.
Arguments
x
The data coming in (whatever it may be).
.name
The name to assign to the output within .env.
.env
The environment within which to save the output at this point. Defaults to the caller env (i.e the env which the pipeline is in).