Learn R Programming

ohvbd (version 1.0.0)

vb_basereq: Generate a base request object for the vectorbyte databases

Description

This request is used as the basis for all calls to the vectorbyte API. It does not contain any tokens or session ids, and thus can be regenerated at any time.

Usage

vb_basereq(
  baseurl = "https://vectorbyte.crc.nd.edu/portal/api/",
  useragent = "ROHVBD",
  unsafe = FALSE,
  .qa = FALSE
)

Value

Returns an httr2 request object, pointing at baseurl using useragent.

Arguments

baseurl

the base url for the vectorbyte API.

useragent

the user agent string used when contacting vectorbyte.

unsafe

disable ssl verification (shouldn't ever be required unless you are otherwise experiencing SSL issues!)

.qa

switch to the vb qa server (only useful for testing).

Author

Francis Windram

Examples

Run this code
basereq <- vb_basereq(
  baseurl="https://vectorbyte.crc.nd.edu/portal/api/",
  useragent="ROHVBD")

Run the code above in your browser using DataLab