powered by
This request is used as the basis for all calls to the vectorbyte API. It does not contain any tokens or session ids, and thus can be regenerated at any time.
vb_basereq( baseurl = "https://vectorbyte.crc.nd.edu/portal/api/", useragent = "ROHVBD", unsafe = FALSE, .qa = FALSE )
Returns an httr2 request object, pointing at baseurl using useragent.
the base url for the vectorbyte API.
the user agent string used when contacting vectorbyte.
disable ssl verification (shouldn't ever be required unless you are otherwise experiencing SSL issues!)
switch to the vb qa server (only useful for testing).
Francis Windram
basereq <- vb_basereq( baseurl="https://vectorbyte.crc.nd.edu/portal/api/", useragent="ROHVBD")
Run the code above in your browser using DataLab