Create a query for a given VD id at a given page
vd_make_req(id, pagenum, rate, url = "", useragent = "", unsafe = FALSE)httr2 request containing the requisite call to retrieve the data.
ID of the vecdyn dataset.
page to retrieve.
rate limit for requests.
the base url for the vectorbyte API.
the user agent string used when contacting vectorbyte.
disable ssl verification (should only ever be required on Linux, do not enable this by default).